# -*- coding: utf-8 -*-
"""
Created on Tue Feb 21 11:44:08 2017

@author: lpa2a
"""


### bring in our text manipulation package
### http://www.nltk.org/
import nltk




### Tokenization - splitting text up into sentences and words

###  bring in a subset for ease of use
from nltk.tokenize import sent_tokenize, word_tokenize

text = "Yoda will always be with you. Your father was seduced by the dark side of the force."

print(sent_tokenize(text))
print(word_tokenize(text))




### Stop Words - common words and how to remove them

### bring in a subset for ease of use
from nltk.corpus import stopwords

stop_words = set(stopwords.words("english"))
words = word_tokenize(text)
filtered_sentence = [ w for w in words if not w.lower() in stop_words]
print(filtered_sentence)




### Stemming - reducing words to their roots or stems

### bring in a subset for ease of use
from nltk.stem import PorterStemmer

ps=PorterStemmer()
example_words=['python','pythoner','pythonic','pythoned']
for word in example_words:    print(ps.stem(word))
    



### Tagging - assigning parts of speech

### list of tags
nltk.help.upenn_tagset()

### bring in a subset for ease of use
from nltk.corpus import state_union
from nltk.tokenize import PunktSentenceTokenizer
   
train_text = state_union.raw("2005-GWBush.txt")
sample_text = state_union.raw("2006-GWBush.txt")
sample_text=text

custom_sent_tokenizer = PunktSentenceTokenizer(train_text)
tokenized=custom_sent_tokenizer.tokenize(sample_text)

def process_content():
    try:
        for i in tokenized:
            words = nltk.word_tokenize(i)
            tagged = nltk.pos_tag(words)
            print(tagged)
    except Exception as e:
        print(str(e))
        
process_content()




### Chunking - ngram by hy hand

def process_content_chunk():
    try:
        for i in tokenized:
            words = nltk.word_tokenize(i)
            tagged = nltk.pos_tag(words)
            
            chunkGram = r"""Chunk: {<MD.?>*<RB.?>*<VB>}"""
#            chunkGram = r"""Chunk: {<RB.?>*<VB.?>*<NNP>+<NN>?}"""
            chunkParser = nltk.RegexpParser(chunkGram)
            chunked=chunkParser.parse(tagged)
            print(chunked) 
            chunked.draw()
            
            
    except Exception as e:
        print(str(e))
        
process_content_chunk()




### N-gram

# bring in a subset for ease of use
from nltk import ngrams

sentence = text
n = 6
sixgrams = ngrams(sentence.split(), n)
for grams in sixgrams:
    print(grams)




### Lemmatization
# similar to stemming but you get a real word

# bring in a subset for ease of use
from nltk.stem import WordNetLemmatizer

lemmatizer = WordNetLemmatizer()

print(lemmatizer.lemmatize("cats"))
print(lemmatizer.lemmatize("geese"))
print(lemmatizer.lemmatize("better"))
print(lemmatizer.lemmatize("better",pos='a'))
# defaults to noun




### wordnet

# bring in a subset for ease of use
from nltk.corpus import wordnet

syns = wordnet.synsets("program")
print(syns)

print(syns[0].lemmas()[0].name())

#definition
print(syns[0].definition())

#examples
print(syns[0].examples())

# example - synonyms and antonnyms
synonyms = []
antonyms = []

for syn in wordnet.synsets("good"):
    for l in syn.lemmas():
        synonyms.append(l.name())
        if l.antonyms():
            antonyms.append(l.antonyms()[0].name())
            
print(set(synonyms))
print(set(antonyms))


#somantic simliarity

w1 = wordnet.synset("ship.n.01")
w2 = wordnet.synset("boat.n.01")
print(w1.wup_similarity(w2))

w1 = wordnet.synset("ship.n.01")
w2 = wordnet.synset("car.n.01")
print(w1.wup_similarity(w2))

w1 = wordnet.synset("ship.n.01")
w2 = wordnet.synset("cat.n.01")
print(w1.wup_similarity(w2))

 